/*
 * tpdfview - src/gtk-tpdfv.h
 * Copyright (C) 2011 Sebastian 'tokkee' Harl <sh@tokkee.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
 * This module provides a Gtk widget to display PDF files.
 */

#ifndef GTK_TPDFV_H
#define GTK_TPDFV_H 1

#include <gtk/gtk.h>

#ifdef __cplusplus
extern "C" {
#endif

#define GTK_TYPE_TPDFV (gtk_tpdfv_get_type())
#define GTK_TPDFV(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST((obj), GTK_TYPE_TPDFV, GtkTPDFV))
#define GTK_TPDFV_CLASS(obj) \
	(G_TYPE_CHECK_CLASS_CAST((obj), GTK_TYPE_TPDFV, GtkTPDFVClass))
#define GTK_IS_TPDFV(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE((obj), GTK_TYPE_TPDFV))
#define GTK_IS_TPDFV_CLASS(obj) \
	(G_TYPE_CHECK_CLASS_TYPE((obj), GTK_TYPE_TPDFV))
#define GTK_TPDFV_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS((obj), GTK_TYPE_TPDFV, GtkTPDFVClass))

GType
gtk_tpdfv_get_type(void);

typedef struct {
	GtkDrawingArea graph;
} GtkTPDFV;

typedef struct {
	GtkDrawingAreaClass parent_class;
} GtkTPDFVClass;

/*
 * gtk_tpdfv_new:
 * Creates a new GtkTPDFV widget to display the specified PDF file.
 */
GtkWidget *
gtk_tpdfv_new(const char *filename);

/*
 * gtk_tpdfv_reload:
 * Reload the previously opened PDF file.
 */
void
gtk_tpdfv_reload(GtkWidget *widget);

/*
 * gtk_tpdfv_get_n_pages, gtk_tpdfv_get_current_page:
 * Get the total number of pages or the current page number.
 */
int
gtk_tpdfv_get_n_pages(GtkWidget *widget);
int
gtk_tpdfv_get_current_page(GtkWidget *widget);

/*
 * gtk_tpdfv_page_up, gtk_tpdfv_page_down,
 * gtk_tpdfv_first_page, gtk_tpdfv_last_page,
 * gtk_tpdfv_goto_page:
 * Navigation (none of these functions will go beyond the first or last page).
 */
void
gtk_tpdfv_page_up(GtkWidget *widget);
void
gtk_tpdfv_page_down(GtkWidget *widget);
void
gtk_tpdfv_first_page(GtkWidget *widget);
void
gtk_tpdfv_last_page(GtkWidget *widget);
void
gtk_tpdfv_goto_page(GtkWidget *widget, int page);

/*
 * gtk_tpdfv_zoom_in, gtk_tpdfv_zoom_out,
 * gtk_tpdfv_zoom_1:
 * Zooming.
 */
void
gtk_tpdfv_zoom_in(GtkWidget *widget);
void
gtk_tpdfv_zoom_out(GtkWidget *widget);
void
gtk_tpdfv_zoom_1(GtkWidget *widget);
void
gtk_tpdfv_zoom_width(GtkWidget *widget);
void
gtk_tpdfv_zoom_height(GtkWidget *widget);
void
gtk_tpdfv_zoom_fit(GtkWidget *widget);

/*
 * gtk_tpdfv_scroll_up, gtk_tpdfv_scroll_down,
 * gtk_tpdfv_scroll_left, gtk_tpdfv_scroll_right:
 * Scrolling.
 */
void
gtk_tpdfv_scroll_up(GtkWidget *widget);
void
gtk_tpdfv_scroll_down(GtkWidget *widget);
void
gtk_tpdfv_scroll_left(GtkWidget *widget);
void
gtk_tpdfv_scroll_right(GtkWidget *widget);

/*
 * Screen handling.
 */

struct gtk_tpdfv_screens;
typedef struct gtk_tpdfv_screens gtk_tpdfv_screens_t;

/*
 * gtk_tpdfv_get_screens:
 * Get a list of available screens.
 */
gtk_tpdfv_screens_t *
gtk_tpdfv_screens_init(const gchar *display_name);
void
gtk_tpdfv_screens_destroy(gtk_tpdfv_screens_t *screens);

/*
 * gtk_tpdfv_screens_number:
 * Get the number of screens.
 */
gint
gtk_tpdfv_screens_number(const gtk_tpdfv_screens_t *screens);

/*
 * gtk_tpdfv_screens_window_set, gtk_tpdfv_screens_window_get:
 * Set or get the screen of a window.
 */
void
gtk_tpdfv_screens_window_set(const gtk_tpdfv_screens_t *screens,
		GtkWindow *window, gint screen);
gint
gtk_tpdfv_screens_window_get(const gtk_tpdfv_screens_t *screens,
		GtkWindow *window);

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* ! GTK_TPDFV_H */

/* vim: set tw=78 sw=4 ts=4 noexpandtab : */

